pub enum SampleError {
Unknown,
Internal,
Resource,
Network,
Hardware,
Protocol,
ProtocolUnrecoverable,
RateLimited,
}Expand description
Reasons sample() may fail.
Variants
Unknown
An error occurred that cannot be classified as one of the more specific error statuses.
Internal
An internal error occurred. This usually indicates a bug in the component implementation.
Resource
A local resource error occurred such as IO, FIDL, or memory allocation failure.
Network
A network error occurred.
Hardware
Some hardware that the time source depends on failed.
Protocol
A retriable error specific to the implemented time protocol occurred, such as a malformed response from a remote server.
ProtocolUnrecoverable
Sampling failed in a nonretriable way. Examples include failed authentication, or a missing configuration.
RateLimited
The request was made too soon and the client should wait before making another request.