pub struct PullSource<UA: UpdateAlgorithm> { /* private fields */ }Expand description
An implementation of |fuchsia.time.external.PullSource| that routes time updates from an |UpdateAlgorithm| to clients of the fidl protocol and routes device property updates from fidl clients to the |UpdateAlgorithm|. This implementation is based on assumption that there’s only one client.
Implementations
Sourceimpl<UA: UpdateAlgorithm> PullSource<UA>
impl<UA: UpdateAlgorithm> PullSource<UA>
Sourcepub fn new(update_algorithm: UA) -> Result<Self, Error>
pub fn new(update_algorithm: UA) -> Result<Self, Error>
Create a new |PullSource| that polls |update_algorithm| for time updates and starts in the |initial_status| status.
Sourcepub async fn handle_requests_for_stream(
&self,
request_stream: PullSourceRequestStream,
inspect_controller: Arc<Mutex<Option<PublishedInspectController>>>,
) -> Result<(), Error>
pub async fn handle_requests_for_stream( &self, request_stream: PullSourceRequestStream, inspect_controller: Arc<Mutex<Option<PublishedInspectController>>>, ) -> Result<(), Error>
Handle a single client’s requests received on the given |request_stream|.